@@ -1,18 +1,15 @@
 from cliff.show import ShowOne
 from cliff.command import Command
 
-from enough import settings
 from enough.common.host import host_factory
+from enough.cli import openstack
 
 
 def set_common_options(parser):
     parser.add_argument('--driver', default='openstack')
-    openstack = parser.add_argument_group(title='OpenStack',
-                                          description='Only when --driver=openstack')
-    openstack.add_argument(
-        '--clouds',
-        default=f'{settings.CONFIG_DIR}/inventory/group_vars/all/clouds.yml',
-        help='Path to the clouds.yml file')
+    o = parser.add_argument_group(title='OpenStack',
+                                  description='Only when --driver=openstack')
+    openstack.set_common_options(o)
     return parser
 
 
