@@ -6,6 +6,48 @@ import shutil
 import yaml
 
 
+class Hosts(object):
+
+    def __init__(self, config_dir):
+        self.d = f'{config_dir}/inventory'
+        self.f = f'{self.d}/hosts.yml'
+        self.load()
+
+    def load(self):
+        if os.path.exists(self.f):
+            self.hosts = yaml.load(open(self.f).read())['all']['hosts']
+        else:
+            self.hosts = {}
+
+    def save(self):
+        if not os.path.exists(self.d):
+            os.makedirs(self.d)
+        content = yaml.dump(
+            {
+                'all': {
+                    'hosts': self.hosts,
+                },
+            }
+        )
+        open(self.f, 'w').write(content)
+
+    def missings(self, names):
+        return [name for name in names if name not in self.hosts]
+
+    def create_or_update(self, name, ipv4):
+        if self.hosts.get(name, {}).get('ansible_host') != ipv4:
+            self.hosts[name] = {'ansible_host': ipv4}
+            self.save()
+            return True
+        else:
+            return False
+
+    def delete(self, name):
+        if name in self.hosts:
+            del self.hosts[name]
+        self.save()
+
+
 class DotEnough(object):
 
     def __init__(self, config_dir, domain):
@@ -30,12 +72,6 @@ class DotEnough(object):
     def private_key(self):
         return self.ensure_ssh_key()
 
-    def populate_hosts_file(self, inventory):
-        d = f'{self.config_dir}/inventory'
-        if not os.path.exists(d):
-            os.makedirs(d)
-        open(f'{d}/hosts.yml', 'w').write(inventory)
-
     def populate_config(self, certificate_authority):
         d = f'{self.config_dir}/inventory/group_vars/all'
         if not os.path.exists(d):
