@@ -1,4 +1,5 @@
 import base64
+import datetime
 import json
 import logging
 import os
@@ -239,16 +240,26 @@ class OpenStackLeftovers(Exception):
     pass
 
 
+class OpenStackBackupCreate(Exception):
+    pass
+
+
 class OpenStack(OpenStackBase):
 
     def __init__(self, config_dir, config_file):
         super().__init__(config_dir, config_file)
         self.config = yaml.load(open(config_file))
-        self.auth = self.config['clouds']['ovh']['auth']
 
     @retry(OpenStackLeftovers, tries=7)
     def destroy_everything(self, prefix):
         leftovers = []
+
+        for snapshot in self.o.volume.snapshot.list('--format=value', '-c', 'Name', _iter=True):
+            snapshot = snapshot.strip()
+            if prefix is None or prefix in snapshot:
+                leftovers.append(f'snapshot({snapshot})')
+                self.o.volume.snapshot.delete(snapshot)
+
         r = self.o.stack.list('--format=json', '-c', 'Stack Name', '-c', 'Stack Status')
         for name, status in [(x["Stack Name"], x["Stack Status"]) for x in json.loads(r.stdout)]:
             if prefix is None or prefix in name:
@@ -262,6 +273,12 @@ class OpenStack(OpenStackBase):
                 leftovers.append(f'image({image})')
                 self.o.image.delete(image)
 
+        for volume in self.o.volume.list('--format=value', '-c', 'Name', _iter=True):
+            volume = volume.strip()
+            if prefix is None or prefix in volume:
+                leftovers.append(f'volume({volume})')
+                self.o.volume.delete(volume)
+
         for network in self.o.network.list('--format=value', '-c', 'Name', _iter=True):
             network = network.strip()
             if prefix is None or prefix in network:
@@ -271,6 +288,9 @@ class OpenStack(OpenStackBase):
         if leftovers:
             raise OpenStackLeftovers('scheduled removal of ' + ' '.join(leftovers))
 
+    def run(self, *args):
+        return self.o(*args)
+
     def network_exists(self, name):
         network = self.o.network.list('--format=value', '-c', 'Name', '--name', name)
         return network.strip() == name
@@ -303,3 +323,56 @@ class OpenStack(OpenStackBase):
         port = self.o.port.list('--server', server, '--network', network,
                                 '--format=value', '-c', 'ID')
         return port.strip() != ''
+
+    def backup_date(self):
+        return datetime.datetime.today().strftime('%Y-%m-%d')
+
+    def backup_create(self, volumes):
+        if len(volumes) == 0:
+            volumes = [x.strip() for x in self.o.volume.list('--format=value', '-c', 'Name')]
+        date = self.backup_date()
+        snapshots = self._backup_map()
+        count = 0
+        for volume in volumes:
+            s = f'{date}-{volume}'
+            if s not in snapshots:
+                self.o.volume.snapshot.create('--force', '--volume', volume, s)
+                count += 1
+        self._backup_available(volumes, date)
+        return count
+
+    def _backup_map(self):
+        return dict(self._backup_list())
+
+    def _backup_list(self):
+        r = self.o.volume.snapshot.list('--format=json', '-c', 'Name', '-c', 'Status',
+                                        '--limit', '5000')
+        return [(x["Name"], x["Status"]) for x in json.loads(r.stdout)]
+
+    @retry(OpenStackBackupCreate, tries=7)
+    def _backup_available(self, volumes, date):
+        available = []
+        waiting = []
+        for name, status in self._backup_list():
+            if not name.startswith(date):
+                continue
+            if status == "available":
+                available.append(name)
+            else:
+                waiting.append(f'{status} {name}')
+        available = ",".join(available)
+        waiting = ",".join(waiting)
+        progress = f'WAITING on {waiting}\nAVAILABLE {available}'
+        log.debug(progress)
+        if len(waiting) > 0:
+            raise OpenStackBackupCreate(progress)
+
+    def backup_prune(self, days):
+        before = (datetime.datetime.today() - datetime.timedelta(days)).strftime('%Y-%m-%d')
+        count = 0
+        for name, status in self._backup_list():
+            if name[:10] > before:
+                continue
+            self.o.volume.snapshot.delete(name)
+            count += 1
+        return count
