@@ -16,37 +16,12 @@ class Service(ABC):
     def __init__(self, config_dir, share_dir):
         self.config_dir = config_dir
         self.share_dir = share_dir
-
-        self.service2hosts = {}
-
-        bind = ['bind-host', 'icinga-host', 'postfix-host', 'wazuh-host']
-        self.service2hosts['bind'] = bind
-
-        cloud = bind[:] + ['cloud-host']
-        self.service2hosts['cloud'] = cloud
-
-        forum = bind[:] + ['forum-host']
-        self.service2hosts['forum'] = forum
-
-        weblate = bind[:] + ['weblate-host']
-        self.service2hosts['weblate'] = weblate
-
-        gitlab = bind[:] + ['gitlab-host', 'runner-host']
-        self.service2hosts['gitlab'] = gitlab
-
-        api = gitlab[:] + ['api-host']
-        self.service2hosts['api'] = api
-
-        chat = bind[:] + ['chat-host']
-        self.service2hosts['chat'] = chat
-
-        packages = bind[:] + ['packages-host']
-        self.service2hosts['packages'] = packages
-
-        website = bind[:] + ['website-host']
-        self.service2hosts['website'] = website
-
-        self.service2hosts['pad'] = website
+        suffix = '-service-hosts'
+        groups = ansible_utils.get_groups()
+        self.service2hosts = {
+            name.replace(suffix, ''): hosts for name, hosts in groups.items()
+            if name.endswith(suffix)
+        }
 
     @abstractmethod
     def create_or_update(self):
