@@ -4,9 +4,6 @@ import dns.resolver
 import gitlab_utils
 from urllib.parse import urlparse
 from bs4 import BeautifulSoup
-import tempfile
-
-from enough.common.openstack import OpenStack
 
 #
 # debug with
@@ -188,54 +185,3 @@ def test_ping(host):
     r = s.get(f'{url}/ping/', timeout=60)
     r.raise_for_status()
     assert 'pong' == r.text
-
-
-def test_create_or_upgrade(host):
-    token = api_sign_in(host)
-    domain = get_domain()
-    url = f"https://api.{domain}"
-    s = requests.Session()
-    s.headers = {'Authorization': f'Token {token}'}
-    s.verify = '../../certs'
-    data = {"name": "bar"}
-    r = s.post(f'{url}/create-or-upgrade/', json=data, timeout=3600)
-    # print(r.text)
-    r.raise_for_status()
-    resolver = dns.resolver.Resolver()
-    bind_ip = str(resolver.query(f'bind.{domain}.')[0])
-    resolver.nameservers = [bind_ip]
-    assert str(resolver.query(f'ns-bar.d.{domain}.', 'a')[0])
-    r = s.delete(f'{url}/hosted/bar/', timeout=600)
-    r.raise_for_status()
-    with host.sudo():
-        content = host.file(
-            f"/root/.enough/bar.d.{domain}/inventory/group_vars/all/clouds.yml").content
-    with tempfile.NamedTemporaryFile() as f:
-        f.write(content)
-        f.flush()
-        o = OpenStack(f.name)
-        o.destroy_everything(None)
-
-
-def test_generate_clouds(host):
-    with host.sudo():
-        cmd = host.run("""
-        apt-get install -y virtualenv gcc libffi-dev libssl-dev python3-dev make
-        virtualenv --python=python3 /tmp/v
-        /tmp/v/bin/pip install python-openstackclient
-        """)
-        print(cmd.stdout)
-        print(cmd.stderr)
-        assert 0 == cmd.rc
-        cmd = host.run("ls /root/.enough/*/api/hosting/all/*")
-        print(cmd.stdout)
-        print(cmd.stderr)
-        assert 0 == cmd.rc
-        for clouds_file in cmd.stdout.split('\n'):
-            print(clouds_file)
-            cmd = host.run(
-                f"OS_CLIENT_CONFIG_FILE={clouds_file} /tmp/v/bin/openstack "
-                "--os-cloud ovh image list")
-            print(cmd.stdout)
-            print(cmd.stderr)
-            assert 0 == cmd.rc
