@@ -1,4 +1,4 @@
-testinfra_hosts = ['cloud-host']
+testinfra_hosts = ['infrastructure1-host']
 
 
 def test_encrypted_volume(host):
