@@ -9,7 +9,8 @@ def test_nextcloud(host):
     d=/dev/sdb
     test -e /dev/sdb || d=/dev/vda
     mount | grep $d | grep /var/lib/docker
-    curl --silent https://cloud.$(hostname -d)/login | grep --quiet 'Forgot pass'
+    curl --silent https://cloud.$(hostname -d)/login |
+       grep --quiet 'This application requires JavaScript'
     """)
     print(cmd.stdout)
     print(cmd.stderr)
@@ -17,10 +18,13 @@ def test_nextcloud(host):
 
 
 def test_nextcloud_via_tor(host):
+    with host.sudo():
+        host.run("apt-get install -y curl")
     cmd = host.run("""
     set -xe
     hostname=$(sudo cat /var/lib/tor/services/cloud/hostname)
-    torsocks curl --silent http://$hostname/login | grep --quiet 'Forgot pass'
+    torsocks curl --silent http://$hostname/login |
+       grep --quiet 'This application requires JavaScript'
     """)
     print(cmd.stdout)
     print(cmd.stderr)
