@@ -81,3 +81,43 @@ def test_playbook_run_no_args(mocker):
     p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
     p.run_from_cli(**kwargs)
     assert 'playbook' in called
+
+
+def test_ansible_inventory():
+    i = ansible_utils.ansible_inventory()
+    assert '_meta' in i
+
+
+def test_get_groups():
+    i = ansible_utils.get_groups()
+    assert 'all-hosts' in i
+
+
+def test_flat_inventory():
+    inventory = {
+        'group1': {
+            'children': ['group2', 'group3'],
+            'hosts': ['host10', 'host11'],
+        },
+        'group2': {
+            'hosts': ['host20'],
+            'children': ['group4'],
+        },
+        'group3': {
+            'hosts': ['host30', 'host31'],
+        },
+        'group4': {
+            'children': ['group5', 'group6'],
+        },
+        'group5': {
+            'hosts': ['host50', 'host51'],
+        },
+        'group6': {},
+        'group7': {
+            'hosts': ['host70', 'host71'],
+        }
+    }
+    expected = ['host10', 'host11', 'host20', 'host30', 'host31', 'host50', 'host51']
+    assert sorted(ansible_utils._flat_inventory(inventory, inventory['group1'])) == expected
+    expected = ['host70', 'host71']
+    assert sorted(ansible_utils._flat_inventory(inventory, inventory['group7'])) == expected
