@@ -19,12 +19,12 @@ def test_openstack_create_or_update(tmpdir, openstack_name, requests_mock):
         'driver': 'openstack',
         'playbook': 'tests/enough/common/test_common_service/enough-playbook.yml',
         'domain': domain,
-        'name': 'bind',
+        'name': 'essential',
     })
     s.dotenough.set_certificate('ownca')
     s.dotenough.set_clouds_file('inventory/group_vars/all/clouds.yml')
     r = s.create_or_update()
-    assert r['fqdn'] == f'bind.{domain}'
+    assert r['fqdn'] == f'essential.{domain}'
     # the second time around the hosts.yml are reused
     r = s.create_or_update()
-    assert r['fqdn'] == f'bind.{domain}'
+    assert r['fqdn'] == f'essential.{domain}'
