@@ -1,9 +1,34 @@
 import os
 import yaml
 
-from enough.common.dotenough import DotEnough, DotEnoughOpenStack
+from enough.common.dotenough import Hosts, DotEnough, DotEnoughOpenStack
 
 
+#
+# Hosts
+#
+def test_hosts_create_delete(tmpdir):
+    config_dir = str(tmpdir)
+    h = Hosts(config_dir)
+    host = 'HOST'
+    ip = '1.2.3.4'
+    assert h.create_or_update(host, ip) is True
+    assert h.create_or_update(host, ip) is False
+    assert os.path.exists(f'{config_dir}/inventory/hosts.yml')
+    h = Hosts(config_dir)
+    assert h.create_or_update(host, ip) is False
+    assert h.hosts[host]['ansible_host'] == ip
+
+    assert h.missings([host, 'MISSING']) == ['MISSING']
+
+    h.delete(host)
+    h = Hosts(config_dir)
+    assert h.hosts == {}
+
+
+#
+# DotEnough
+#
 def test_remap():
     p = '.enough/thing'
     unchanged = '/foo/bar/'
