@@ -148,3 +148,26 @@ def test_network(openstack_name):
     o.network_and_subnet_create(openstack_name, '10.11.12.0/24')
     assert o.network_exists(openstack_name)
     assert o.subnet_exists(openstack_name)
+
+
+@pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
+                    reason='skip integration test')
+def test_backup_create_with_name(openstack_name, caplog):
+    o = OpenStack(settings.CONFIG_DIR, 'inventory/group_vars/all/clouds.yml')
+    o.o.volume.create('--size=1', openstack_name)
+    assert o.backup_create([openstack_name]) == 1
+    assert o.backup_create([openstack_name]) == 0
+    available_snapshot = f'AVAILABLE {o.backup_date()}-{openstack_name}'
+    assert available_snapshot in caplog.text
+    assert o.backup_prune(0) == 1
+    assert o.backup_prune(0) == 0
+
+
+@pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
+                    reason='skip integration test')
+def test_backup_create_no_names(openstack_name, caplog):
+    o = OpenStack(settings.CONFIG_DIR, 'inventory/group_vars/all/clouds.yml')
+    o.o.volume.create('--size=1', openstack_name)
+    o.backup_create([])
+    available_snapshot = f'AVAILABLE {o.backup_date()}-{openstack_name}'
+    assert available_snapshot in caplog.text
