@@ -1,3 +1,4 @@
+from tests.modified_environ import modified_environ
 from enough import cmd
 
 
@@ -28,3 +29,15 @@ def test_service(capsys, mocker):
     assert cmd.main(['--debug', 'service', 'create', name]) == 0
     out, err = capsys.readouterr()
     assert fqdn in out
+
+
+def test_openstack(capsys, mocker):
+    # do not tamper with logging streams to avoid
+    # ValueError: I/O operation on closed file.
+    mocker.patch('cliff.app.App.configure_logging')
+    mocker.patch('enough.common.openstack.OpenStack.run',
+                 side_effect=lambda *args, **kwargs: print('OPENSTACK'))
+    with modified_environ(OS_CLIENT_CONFIG_FILE="/dev/null"):
+        assert cmd.main(['openstack', '--debug', 'help']) == 0
+    out, err = capsys.readouterr()
+    assert 'OPENSTACK' in out
